@@ -52,27 +52,27 @@
 #include <pyside2_qtcore_python.h>
 
 // Binded library includes
-#include <qabstractaxisinput.h>
-#include <qaxis.h>
-#include <qaxissetting.h>
-#include <qactioninput.h>
-#include <qinputsettings.h>
-#include <qmousedevice.h>
-#include <qabstractphysicaldevice.h>
-#include <qkeyevent.h>
-#include <qbuttonaxisinput.h>
-#include <qinputchord.h>
-#include <qinputaspect.h>
-#include <qanalogaxisinput.h>
-#include <qkeyboarddevice.h>
-#include <qaxisaccumulator.h>
-#include <qaction.h>
-#include <qinputsequence.h>
-#include <qmousehandler.h>
-#include <qlogicaldevice.h>
-#include <qkeyboardhandler.h>
-#include <qabstractactioninput.h>
-#include <qmouseevent.h>
+#include <Qt3DInput/qaxisaccumulator.h>
+#include <Qt3DInput/qinputsettings.h>
+#include <Qt3DInput/qabstractactioninput.h>
+#include <Qt3DInput/qabstractaxisinput.h>
+#include <Qt3DInput/qaction.h>
+#include <Qt3DInput/qkeyboardhandler.h>
+#include <Qt3DInput/qinputchord.h>
+#include <Qt3DInput/qabstractphysicaldevice.h>
+#include <Qt3DInput/qinputsequence.h>
+#include <Qt3DInput/qkeyboarddevice.h>
+#include <Qt3DInput/qmousehandler.h>
+#include <Qt3DInput/qaxissetting.h>
+#include <Qt3DInput/qbuttonaxisinput.h>
+#include <Qt3DInput/qactioninput.h>
+#include <Qt3DInput/qlogicaldevice.h>
+#include <Qt3DInput/qmousedevice.h>
+#include <Qt3DInput/qinputaspect.h>
+#include <Qt3DInput/qkeyevent.h>
+#include <Qt3DInput/qanalogaxisinput.h>
+#include <Qt3DInput/qmouseevent.h>
+#include <Qt3DInput/qaxis.h>
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
@@ -93,7 +93,7 @@
 
 // Type indices
 enum : int {
-    SBK_QT3DINPUT_IDX                                        = 0,
+    SBK_Qt3DInputQT3DINPUT_IDX                               = 0,
     SBK_QT3DINPUT_QABSTRACTACTIONINPUT_IDX                   = 1,
     SBK_QT3DINPUT_QABSTRACTAXISINPUT_IDX                     = 2,
     SBK_QT3DINPUT_QABSTRACTPHYSICALDEVICE_IDX                = 3,
@@ -125,13 +125,13 @@ enum : int {
     SBK_Qt3DInput_IDX_COUNT                                  = 29
 };
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_Qt3DInputTypes;
+extern PyTypeObject **SbkPySide2_Qt3DInputTypes;
 
 // This variable stores the Python module object exported by this module.
-extern PyObject* SbkPySide2_Qt3DInputModuleObject;
+extern PyObject *SbkPySide2_Qt3DInputModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_Qt3DInputTypeConverters;
+extern SbkConverter **SbkPySide2_Qt3DInputTypeConverters;
 
 // Converter indices
 enum : int {
@@ -156,34 +156,34 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QAbstractActionInput >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QABSTRACTACTIONINPUT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QAbstractAxisInput >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QABSTRACTAXISINPUT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QAbstractPhysicalDevice >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QABSTRACTPHYSICALDEVICE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QAction >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QACTION_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QActionInput >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QACTIONINPUT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QAnalogAxisInput >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QANALOGAXISINPUT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QAxis >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QAXIS_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QAxisAccumulator::SourceAxisType >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QAXISACCUMULATOR_SOURCEAXISTYPE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QAxisAccumulator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QAXISACCUMULATOR_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QAxisSetting >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QAXISSETTING_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QButtonAxisInput >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QBUTTONAXISINPUT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QInputAspect >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QINPUTASPECT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QInputChord >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QINPUTCHORD_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QInputSequence >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QINPUTSEQUENCE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QInputSettings >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QINPUTSETTINGS_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QKeyEvent >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QKEYEVENT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QKeyboardDevice >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QKEYBOARDDEVICE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QKeyboardHandler >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QKEYBOARDHANDLER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QLogicalDevice >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QLOGICALDEVICE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QMouseDevice::Axis >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX]; }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QMouseDevice >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QMouseEvent::Buttons >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEEVENT_BUTTONS_IDX]; }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QMouseEvent::Modifiers >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEEVENT_MODIFIERS_IDX]; }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QMouseEvent >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEEVENT_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QMouseHandler >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEHANDLER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QWheelEvent::Buttons >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QWHEELEVENT_BUTTONS_IDX]; }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QWheelEvent::Modifiers >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QWHEELEVENT_MODIFIERS_IDX]; }
-template<> inline PyTypeObject* SbkType< ::Qt3DInput::QWheelEvent >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QWHEELEVENT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QAbstractActionInput >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QABSTRACTACTIONINPUT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QAbstractAxisInput >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QABSTRACTAXISINPUT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QAbstractPhysicalDevice >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QABSTRACTPHYSICALDEVICE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QAction >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QACTION_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QActionInput >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QACTIONINPUT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QAnalogAxisInput >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QANALOGAXISINPUT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QAxis >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QAXIS_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QAxisAccumulator::SourceAxisType >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QAXISACCUMULATOR_SOURCEAXISTYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QAxisAccumulator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QAXISACCUMULATOR_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QAxisSetting >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QAXISSETTING_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QButtonAxisInput >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QBUTTONAXISINPUT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QInputAspect >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QINPUTASPECT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QInputChord >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QINPUTCHORD_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QInputSequence >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QINPUTSEQUENCE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QInputSettings >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QINPUTSETTINGS_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QKeyEvent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QKEYEVENT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QKeyboardDevice >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QKEYBOARDDEVICE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QKeyboardHandler >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QKEYBOARDHANDLER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QLogicalDevice >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QLOGICALDEVICE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QMouseDevice::Axis >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_AXIS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QMouseDevice >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEDEVICE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QMouseEvent::Buttons >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEEVENT_BUTTONS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QMouseEvent::Modifiers >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEEVENT_MODIFIERS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QMouseEvent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEEVENT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QMouseHandler >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QMOUSEHANDLER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QWheelEvent::Buttons >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QWHEELEVENT_BUTTONS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QWheelEvent::Modifiers >() { return SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QWHEELEVENT_MODIFIERS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DInput::QWheelEvent >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DInputTypes[SBK_QT3DINPUT_QWHEELEVENT_IDX]); }
 
 } // namespace Shiboken
 
