@@ -46,73 +46,72 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtcore_python.h>
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtwidgets_python.h>
 
 // Binded library includes
-#include <qtestmouse.h>
-#include <qtestkeyboard.h>
-#include <qttestglobal.h>
-#include <qbenchmarkmetric.h>
+#include <QtTest/qtestmouse.h>
+#include <QtTest/qttestglobal.h>
+#include <QtTest/qbenchmarkmetric.h>
+#include <QtTest/qtestkeyboard.h>
 #include <pysideqtesttouch.h>
 // Conversion Includes - Primitive Types
-#include <QStringList>
-#include <QString>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
+#include <QString>
+#include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QSet>
-#include <QList>
-#include <QMultiMap>
-#include <QMap>
+#include <pysideqflags.h>
 #include <QLinkedList>
+#include <QList>
+#include <QMap>
+#include <QMultiMap>
+#include <QPair>
+#include <QQueue>
+#include <QSet>
 #include <QStack>
 #include <QVector>
-#include <QQueue>
-#include <QPair>
-#include <pysideqflags.h>
 
 // Type indices
-#define SBK_QTEST_IDX                                                0
-#define SBK_QTEST_TESTFAILMODE_IDX                                   5
-#define SBK_QTEST_QBENCHMARKMETRIC_IDX                               4
-#define SBK_QTEST_KEYACTION_IDX                                      1
-#define SBK_QTEST_MOUSEACTION_IDX                                    2
-#define SBK_QTEST_PYSIDEQTOUCHEVENTSEQUENCE_IDX                      3
-#define SBK_QtTest_IDX_COUNT                                         6
-
+enum : int {
+    SBK_QtTestQTEST_IDX                                      = 0,
+    SBK_QTEST_TESTFAILMODE_IDX                               = 5,
+    SBK_QTEST_QBENCHMARKMETRIC_IDX                           = 4,
+    SBK_QTEST_KEYACTION_IDX                                  = 1,
+    SBK_QTEST_MOUSEACTION_IDX                                = 2,
+    SBK_QTEST_PYSIDEQTOUCHEVENTSEQUENCE_IDX                  = 3,
+    SBK_QtTest_IDX_COUNT                                     = 6
+};
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtTestTypes;
+extern PyTypeObject **SbkPySide2_QtTestTypes;
+
+// This variable stores the Python module object exported by this module.
+extern PyObject *SbkPySide2_QtTestModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtTestTypeConverters;
+extern SbkConverter **SbkPySide2_QtTestTypeConverters;
 
 // Converter indices
-#define SBK_QTTEST_QLIST_QVARIANT_IDX                                0 // QList<QVariant >
-#define SBK_QTTEST_QLIST_QSTRING_IDX                                 1 // QList<QString >
-#define SBK_QTTEST_QMAP_QSTRING_QVARIANT_IDX                         2 // QMap<QString,QVariant >
-#define SBK_QtTest_CONVERTERS_IDX_COUNT                              3
-
+enum : int {
+    SBK_QTTEST_QLIST_QVARIANT_IDX                            = 0, // QList<QVariant >
+    SBK_QTTEST_QLIST_QSTRING_IDX                             = 1, // QList<QString >
+    SBK_QTTEST_QMAP_QSTRING_QVARIANT_IDX                     = 2, // QMap<QString,QVariant >
+    SBK_QtTest_CONVERTERS_IDX_COUNT                          = 3
+};
 // Macros for type check
 
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QTest::TestFailMode >() { return SbkPySide2_QtTestTypes[SBK_QTEST_TESTFAILMODE_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QTest::QBenchmarkMetric >() { return SbkPySide2_QtTestTypes[SBK_QTEST_QBENCHMARKMETRIC_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QTest::KeyAction >() { return SbkPySide2_QtTestTypes[SBK_QTEST_KEYACTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QTest::MouseAction >() { return SbkPySide2_QtTestTypes[SBK_QTEST_MOUSEACTION_IDX]; }
-template<> inline PyTypeObject* SbkType< ::QTest::PySideQTouchEventSequence >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtTestTypes[SBK_QTEST_PYSIDEQTOUCHEVENTSEQUENCE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QTest::TestFailMode >() { return SbkPySide2_QtTestTypes[SBK_QTEST_TESTFAILMODE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QTest::QBenchmarkMetric >() { return SbkPySide2_QtTestTypes[SBK_QTEST_QBENCHMARKMETRIC_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QTest::KeyAction >() { return SbkPySide2_QtTestTypes[SBK_QTEST_KEYACTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QTest::MouseAction >() { return SbkPySide2_QtTestTypes[SBK_QTEST_MOUSEACTION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QTest::PySideQTouchEventSequence >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtTestTypes[SBK_QTEST_PYSIDEQTOUCHEVENTSEQUENCE_IDX]); }
 
 } // namespace Shiboken
 
